<?php

namespace HPROWP\Core;

/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

class Autoload {
    
    protected $prefix = '';
    protected $basePath = '';
    protected $aliases = '';
    protected $files = '';
    protected $enabled = true;
    
    public function __construct($prefix, $basePath, $aliases = array(), $files = array()) {
        $this->prefix = $prefix;
        $this->basePath = $basePath;
        $this->aliases = $aliases;
        $this->files = $files;
        
        spl_autoload_register(array(&$this, 'request'));
    }
    
    public function enable() {
        $this->enabled = true;
        return $this;
    }
    
    public function disable() {
        $this->enabled = false;
        return $this;
    }
    
    public function isEnabled() {
        return $this->enabled;
    }
    
    protected function resolve($class) {
        if ($this->isEnabled()) {
            $isNameSpace = strstr($this->prefix, '\\') !== false;

            $decodedClass = $class;

            if (isset($this->aliases[$decodedClass])) {
                $decodedClass = $this->aliases[$decodedClass];
            }

            if (isset($this->files[$decodedClass])) {
                $decodedFile = $this->files[$decodedClass];
                return file_exists($decodedFile) 
                    ? $decodedFile 
                    : $file = $this->basePath . DIRECTORY_SEPARATOR . $decodedFile;
            }

            $len = strlen($this->prefix);
            if (strncmp($this->prefix, $decodedClass, $len) !== 0) {
                // no, move to the next registered autoloader
                return false;
            }

        // get the relative class name
            $relative_class = substr($decodedClass, $len);

        // replace the namespace prefix with the base directory, replace namespace
        // separators with directory separators in the relative class name, append
        // with .php
            $file = $this->basePath . DIRECTORY_SEPARATOR
                    . str_replace(array('_', '\\'), DIRECTORY_SEPARATOR, $relative_class) . '.php';

            if (!$isNameSpace) {
                $file = strtolower($file);
            }

            // if the file exists, require it
            if (file_exists($file)) {
                return $file;
            }
        }
        return false;
    }
    
    public function request($class) {
        $require = $this->resolve($class);
        if ($require) {
            require_once $require;
        }
    }
    
    public function register($prefix, $basePath, $aliases = array(), $files = array()) {
        
    }
    
    public static function factory($autoloaders = array()) {
        if (count($autoloaders) > 0) {
            foreach ($autoloaders as $loaderConfig) {
                $loaderClass = isset($loaderConfig['class']) ? $loaderConfig['class'] : '\\PNP\\Core\\Autoload';
                $loaderProviderClass = isset($loaderConfig['provider']) ? $loaderConfig['provider'] : false;

                if ($loaderClass) {
                    $pluginLoader = new $loaderClass(
                        $loaderConfig['prefix'],
                        $loaderConfig['base'],
                        isset($loaderConfig['aliases']) ? $loaderConfig['aliases'] : array(),
                        isset($loaderConfig['files']) ? $loaderConfig['files'] : array()
                    );
                }
                else if ($loaderProviderClass) {
                    Provider::factory($loaderProviderClass)->register(
                        $loaderConfig['prefix'],
                        $loaderConfig['base'],
                        isset($loaderConfig['aliases']) ? $loaderConfig['aliases'] : array(),
                        isset($loaderConfig['files']) ? $loaderConfig['files'] : array()
                    );
                }
            }
        }
    }
}