<?php

namespace HPROWP\Core;

/**
 * Default builder class
 * @author dzonz
 *
 */
class Components {

    private static $_instances = array();
    private static $_components = array();
    
    public static function service($component, $componentClass) {
        self::$_components[$component] = [
            "type" => 'service',
            "class" => $componentClass
        ];
    }
    
    public static function component($component, $componentClass) {
        self::$_components[$component] = [
            "type" => 'component',
            "class" => $componentClass
        ];
    }
    
    /**
     * 
     * @param string $component
     * @return string
     */
    public static function resolve($componentClass) {
        $componentConfiguration = [
            "type" => 'component',
            "class" => $componentClass
        ];
        
        while (true) {
            if (!isset(self::$_components[$componentConfiguration['class']])) {
                break;
            }
            
            $componentConfiguration = self::$_components[$componentConfiguration['class']];
        }
        
        return $componentConfiguration;
    }

    public static function invoke($component, $config = null) {
        $registeredComponentConfiguration = self::resolve($component);
        
        if (!$registeredComponentConfiguration) {
            throw new \Exception('Component not found');
        }

        $registeredComponentClass = $registeredComponentConfiguration['class'];
        $registeredComponentType = $registeredComponentConfiguration['type'];

        switch ($registeredComponentType) {
            case 'service':
                return self::invokeService($registeredComponentConfiguration, $config);
                break;
            case 'component':
                return self::invokeComponent($registeredComponentConfiguration, $config);
                break;
            default:
                throw new \Exception('Component not supported');
        }
    }

    protected static function invokeService($registeredComponentConfiguration = null, $config = null) {
        if (!$registeredComponentConfiguration) {
            throw new \Exception('Component invalid');
        }

        $registeredComponentClass = $registeredComponentConfiguration['class'];
        $registeredComponentType = $registeredComponentConfiguration['type'];

        if (!isset(self::$_instances[$registeredComponentClass])) {
            $componentInstance = new $registeredComponentClass();
            self::$_instances[$registeredComponentClass] = $componentInstance;
            Initializer::initialize($componentInstance, $config);
        }

        return self::$_instances[$registeredComponentClass];
    }

    public static function invokeComponent($registeredComponentConfiguration = null, $config = null) {
        if (!$registeredComponentConfiguration) {
            throw new \Exception('Component invalid');
        }
        
        $registeredComponentClass = $registeredComponentConfiguration['class'];

        $componentInstance = new $registeredComponentClass();
        Initializer::initialize($componentInstance, $config);

        return $componentInstance;
    }

    protected function __construct() {
        
    }
    
}
