<?php

namespace HPROWP;

class 
Plugin 
extends 
Core\ComponentAbstract
implements 
Core\PluginInitializerInterface,
Core\PagesInitializerInterface,
Core\PluginTextDomainInitializerInterface
{
    public function getPluginTextDomain() {
        return [
            'hpro-webpush', basename( dirname( HPROWP_PLUGIN_FILE ) ) . '/languages'
        ];
    }

    /** Pages Interface */
    public function getPages() {
        return [
            [
                'title' => __('nGage Webpush'),
                'label' => __('nGage Webpush'),
                'onRender' => [$this, 'onRenderWebPushGeneral'],
                'onLoad' => [$this, 'onLoadWebPushGeneral'],
                'slug' => 'horisen_webpush_page_general',
                'position' => 65,
                'icon' => 'dashicons-format-status',
                'menu_icon'   => 'dashicons-format-status',
                'pages' => [
                    [
                        'title' => __('General', 'hpro-webpush'),
                        'label' => __('General', 'hpro-webpush'),
                        'onRender' => [$this, 'onRenderWebPushGeneral'],
                        'onLoad' => [$this, 'onLoadWebPushGeneral'],
                        'slug' => 'horisen_webpush_page_general',
                    ],
                    [
                        'title' => __('Notify button', 'hpro-webpush' ),
                        'label' => __('Notify button', 'hpro-webpush' ),
                        'onRender' => [$this, 'onRenderWebPushNotifyButton'],
                        'onLoad' => [$this, 'onLoadWebPushNotifyButton'],
                        'slug' => 'horisen_webpush_page_notify_button',
                    ]
                ]
            ]
        ];
    }

    public function onLoad() {
?>
<?php
    }

    public function onRender() {
?>
<h1>onRender</h1>
<?php
    }

    public function onLoadWebPushGeneral() {
?>
<?php
    }
    public function onLoadWebPushNotifyButton() {
?>
<?php
    }

    public function themeInitAdmin() {
        $this->generalSettingsPage = new Webpush\GeneralSettings();
        $this->buttonSettingsPage = new Webpush\ButtonSettings();
    }

    public function onRenderWebPushGeneral() {
        $this->generalSettingsPage->render();
    }
    public function onRenderWebPushNotifyButton() {
        $this->buttonSettingsPage->render();
    }
    public function webpushImportScript() {
        $generalOptions = Webpush\GeneralSettings::getOptions();
        $buttonOptions = Webpush\ButtonSettings::getOptions();
        $settings = [
            'formUuid' => $generalOptions['form_uuid'],
            'applicationServerKey' => $generalOptions['application_server_key'],
            'notifyButton' => [
                'enable' => isset($buttonOptions['notify_button']) ? $buttonOptions['notify_button'] : false,
                'hideAfterSubscribe' => isset($buttonOptions['hide_after_subscribe']) ? $buttonOptions['hide_after_subscribe'] : false,
                'position' => isset($buttonOptions['notify_button_position']) ? $buttonOptions['notify_button_position'] : 'bottom-right',
                'theme' => $buttonOptions['notify_button_theme'], 
                'tooltip' => [
                     'subscribe' => $buttonOptions['tooltip_subscribe'],
                     'unsubscribe' => $buttonOptions['tooltip_unsubscribe'],
                 ],
                 'notification' => [
                     'subscribe' => $buttonOptions['notification_subscribe'],
                     'unsubscribe' => $buttonOptions['notification_unsubscribe'],
                     'error' => $buttonOptions['notification_error'],
                 ],
                 'dialog' => [
                     'subscribe' => $buttonOptions['dialog_subscribe'],
                     'unsubscribe' => $buttonOptions['dialog_unsubscribe'],
                 ]
            ]
        ];
        
        foreach ($settings['notifyButton'] as $key => $value) {
            if(is_array($settings['notifyButton'][$key])){
                foreach ($settings['notifyButton'][$key] as $k => $v) {
                    if(!isset($v) || $v == ''){
                         unset($settings['notifyButton'][$key][$k]);
                    }
                }
                if(sizeof($settings['notifyButton'][$key]) == 0) unset($settings['notifyButton'][$key]);
            }
            if(!isset($value)){
                unset($settings['notifyButton'][$key]);
            }
        }
        $script = '<script language="javascript" type="text/javascript">
            var hproWebPush = hproWebPush || [];
                hproWebPush.init('.json_encode($settings, JSON_FORCE_OBJECT).');
        </script>';
        echo $script;
    }

    /** Plugin Interface */
    public function getSdkVersion(){
        $version = Webpush\GeneralSettings::getOptions();
        if(!isset($version['sdk_version'])){
            return 'latest';
        }
        return $version['sdk_version'];
    }
    public function pluginActivate() {
        Webpush\ButtonSettings::initialOptions();
    }

    public function pluginDeactivate() {

    }

    public function pluginHook() {
        return HPROWP_PLUGIN_FILE;
    }

    /** Theme Interface */
    protected function registerScripts() {
//         wp_register_script('hproWebpushSDK', 'https://demo.horisen.dev/horisen_components/horisen-webpush-sdk/dist/hpro-wp-sdk.js', array(), null, false);
         wp_register_script('hproWebpushSDK', 'https://content.horisen.pro/js/webpush/'. $this->getSdkVersion() .'/hpro-wp-sdk.js', array(), null, false);
         wp_enqueue_script('hproWebpushSDK');   

    }
    
    
    
    protected function registerStyles() {
        /* wp_register_style('mdl',                PNP_PLUGIN_URI . 'components/material-design-lite/material.min.css', array());
        wp_register_style('mdi',                PNP_PLUGIN_URI . 'components/mdi/css/materialdesignicons.min.css', array());
        wp_register_style('pnp-ng',             PNP_PLUGIN_URI . 'app/css/pnp.css', array('mdl', 'mdi')); */
    }
    
    public function themePublicScripts() {
        $this->registerScripts();
    }
    
    public function themePublicStyles() {
        $this->registerStyles();
    }
    
    public function themeAdminScripts() {
        $this->registerScripts();
    }
    
    public function themeAdminStyles() {
        $this->registerStyles();
    }

    public function themeBootstrap() {
    global $wpdb;
    
        /* $wpdb->taxonomymeta = $wpdb->prefix . "taxonomymeta";

        add_action('before_delete_post', array(&$this, 'extendDeletePost'), 10, 1);
        add_filter('body_class', array(&$this, 'extendBodyClass'), 10, 2);
        add_action('posts_clauses', array(&$this, 'extendPostsClauses'), 9, 2);
        add_action('pre_get_posts', array(&$this, 'extendPreGetPosts'), 9, 2);
        add_filter('parse_query', array(&$this, 'extendParseQuery'), 9, 2); */
    }
    
    public function themeSelect() {
    /* global $wpdb;

        $wpdb->taxonomymeta = "{$wpdb->prefix}taxonomymeta";

        $charset_collate = '';
        if (!empty($wpdb->charset)) {
            $charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
        }
        if (!empty($wpdb->collate)) {
            $charset_collate .= " COLLATE $wpdb->collate";
        }

        $tables = $wpdb->get_results("show tables like '{$wpdb->prefix}taxonomymeta'");
        if (!count($tables)) {
            $wpdb->query(
                "CREATE TABLE {$wpdb->prefix}taxonomymeta (
                meta_id bigint(20) unsigned NOT NULL auto_increment,
                taxonomy_id bigint(20) unsigned NOT NULL default '0',
                meta_key varchar(255) default NULL,
                meta_value longtext,
                PRIMARY KEY (meta_id),
                KEY taxonomy_id (taxonomy_id),
                KEY meta_key (meta_key)
            ) $charset_collate;");
        } */
    }

    public function themeDeselect() {

    }

    public function themeInit() {

    }

    public function themeSetup() {

    }
}