<?php

namespace HPROWP\Webpush;

class ButtonSettings 
extends BaseSettings {
    
    protected $settings = 'button';
    
    public static function getOptions() {
        return get_option('horisen_webpush_button_settings', array() );
    }
    public static function initialOptions() {
        update_option( 'horisen_webpush_button_settings', [
            'tooltip_subscribe' => 'Subscribe to notifications',
            'tooltip_unsubscribe' => 'Unsubscribe from notifications',
            'notification_subscribe' => 'You are successfully subscribed to notifications',
            'notification_unsubscribe' => 'You have unsubscribed from notifications',
            'notification_error' => 'Subscribed to notifications failed',
            'dialog_subscribe' => 'Are you sure you want to subscribe to notifications?',
            'dialog_unsubscribe' => 'Are you sure you want to unsubscribe from notifications?',
        ] );
    }
    
    public function __construct() {
        parent::__construct();
        
        register_setting(
            $this->optionsGroup, // Option group
            $this->optionsKey, // Option name
            array( $this, 'sanitize' ) // Sanitize
        );
        
        add_settings_section(
            $this->optionsSection, // ID
            __('Notify Button Settings', 'hpro-webpush'), // Title
            array( $this, 'print_section_info' ), // Callback
            $this->optionsPage // Page
        ); 
        
        //Notify button settings
        add_settings_field(
            'notify_button', // ID
            __('Enable', 'hpro-webpush'), // Title 
            array( $this, 'notify_button_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section           
        );
        
        
        add_settings_field(
            'notify_button_position', // ID
            __('Position', 'hpro-webpush'), // Title 
            array( $this, 'notify_button_position_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        
        add_settings_field(
            'notify_button_theme', // ID
            __('Theme', 'hpro-webpush'), // Title 
            array( $this, 'notify_button_theme_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        
        add_settings_field(
            'hide_after_subscribe', // ID
            __('Hidden', 'hpro-webpush'), // Title 
            array( $this, 'hide_after_subscribe_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        
        add_settings_field(
            'tooltip_subscribe', // ID
            __('Tooltip subscribe text', 'hpro-webpush'), // Title 
            array( $this, 'tooltip_subscribe_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        
        add_settings_field(
            'tooltip_unsubscribe', // ID
            __('Tooltip unsubscribe text', 'hpro-webpush'), // Title
            array( $this, 'tooltip_unsubscribe_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        add_settings_field(
            'dialog_subscribe', // ID
            __('Dialog subscribe text', 'hpro-webpush'), // Title
            array( $this, 'dialog_subscribe_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        
        add_settings_field(
            'dialog_unsubscribe', // ID
            __('Dialog unsubscribe text', 'hpro-webpush'), // Title
            array( $this, 'dialog_unsubscribe_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        add_settings_field(
            'notification_subscribe', // ID
            __('Notification subscribe text', 'hpro-webpush'), // Title 
            array( $this, 'notification_subscribe_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        
        add_settings_field(
            'notification_unsubscribe', // ID
            __('Notification unsubscribe text', 'hpro-webpush'), // Title 
            array( $this, 'notification_unsubscribe_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        add_settings_field(
            'notification_error', // ID
            __('Notification error text', 'hpro-webpush'), // Title 
            array( $this, 'notification_error_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
    }

    protected function renderSettings() {
        parent::renderSettings();        
    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize( $input )
    {
        $new_input = array();
        
        if( isset( $input['notify_button'] ) )
            $new_input['notify_button'] = "true";
        
        if( isset( $input['notify_button_position'] ) )
            $new_input['notify_button_position'] = sanitize_text_field( $input['notify_button_position'] );
        
        if( isset( $input['notify_button_theme'] ) )
            $new_input['notify_button_theme'] = sanitize_text_field( $input['notify_button_theme'] );
        
        if( isset( $input['hide_after_subscribe'] ) ) 
            $new_input['hide_after_subscribe'] = "true";
        
        if( isset( $input['tooltip_subscribe'] ) )
            $new_input['tooltip_subscribe'] = sanitize_text_field( $input['tooltip_subscribe'] );
        
        if( isset( $input['tooltip_unsubscribe'] ) )
            $new_input['tooltip_unsubscribe'] = sanitize_text_field( $input['tooltip_unsubscribe'] );
        
        if( isset( $input['dialog_subscribe'] ) )
            $new_input['dialog_subscribe'] = sanitize_text_field( $input['dialog_subscribe'] );
        
        if( isset( $input['dialog_unsubscribe'] ) )
            $new_input['dialog_unsubscribe'] = sanitize_text_field( $input['dialog_unsubscribe'] );
        
        if( isset( $input['notification_subscribe'] ) )
            $new_input['notification_subscribe'] = sanitize_text_field( $input['notification_subscribe'] );
        
        if( isset( $input['notification_unsubscribe'] ) )
            $new_input['notification_unsubscribe'] = sanitize_text_field( $input['notification_unsubscribe'] );
        
        if( isset( $input['notification_error'] ) )
            $new_input['notification_error'] = sanitize_text_field( $input['notification_error'] );
            
        return $new_input;
    }

    public function print_section_info(){
        print __("Check option 'enable', if you want to activate subscription button.", 'hpro-webpush');
    }

    public function notify_button_callback(){
        printf(
            '<input type="checkbox" id="notify_button" name="' . $this->optionsKey . '[notify_button]" value="%s" %s>',
            isset( $this->options['notify_button']) ? 'true' : 'false',
            isset( $this->options['notify_button']) ? 'checked="checked"' : ''
        );
    }
    
    public function notify_button_position_callback() {
        $key = 'notify_button_position';
        $options = [
            'top-left' => __('Top - Left', 'hpro-webpush'),
            'top-right' => __('Top - Right', 'hpro-webpush'),
            'bottom-left' => __('Bottom - Left', 'hpro-webpush'),
            'bottom-right' => __('Bottom - Right', 'hpro-webpush')
        ];

        echo '<select id="' . $key . '" name="' . $this->optionsKey . '[' . $key . ']" data-group="' . $key . '">';
        foreach ($options as $optKey => $optValue) {
            echo '<option value="' . $optKey . '" ' 
                . ($this->options[$key] == $optKey ? ' selected="selected" ' : '') . '>' . $optValue . '</option>';
        }
        echo '</select>';
    }
    public function notify_button_theme_callback(){
        $key = 'notify_button_theme';
        $options = [
            'default' => __('Default', 'hpro-webpush'),
            'light' => __('Light', 'hpro-webpush'),
            'dark' => __('Dark', 'hpro-webpush'),
            'iceberg' => __('Iceberg', 'hpro-webpush')
        ];

        echo '<select id="' . $key . '" name="' . $this->optionsKey . '[' . $key . ']" data-group="' . $key . '">';
        foreach ($options as $optKey => $optValue) {
            echo '<option value="' . $optKey . '" ' 
                . ($this->options[$key] == $optKey ? ' selected="selected" ' : '') . '>' . $optValue . '</option>';
        }
        echo '</select>';
    }

    public function hide_after_subscribe_callback(){
        printf(
            '<input type="checkbox" id="hide_after_subscribe" name="' . $this->optionsKey . '[hide_after_subscribe]" data-group="notify_button" %s>'.
            '<p class="description">%s</p>',
            isset( $this->options['']) ? 'checked="checked"' : '',
            __('Hide button after subscription', 'hpro-webpush')
        );
    }
    
    public function tooltip_subscribe_callback(){
        printf(
            '<input type="text" id="tooltip_subscribe" name="' . $this->optionsKey . '[tooltip_subscribe]" data-group="notify_button" style="width: 430px;" value="%s" />'.
            '<p class="description">%s</p>',
            isset( $this->options['tooltip_subscribe'] ) ? esc_attr( $this->options['tooltip_subscribe']) : '',
            __('Tooltip message when you are not subscribed and hover notify button', 'hpro-webpush')
        );
    }
    public function tooltip_unsubscribe_callback(){
        printf(
            '<input type="text" id="tooltip_unsubscribe" name="' . $this->optionsKey . '[tooltip_unsubscribe]" data-group="notify_button" style="width: 430px;" value="%s" />'.
            '<p class="description">%s</p>',
            isset( $this->options['tooltip_unsubscribe'] ) ? esc_attr( $this->options['tooltip_unsubscribe']) : '',
            __('Tooltip message when you are subscribed and hover notify button', 'hpro-webpush')
        );
    }
    public function notification_subscribe_callback(){
        printf(
            '<input type="text" id="notification_subscribe" name="' . $this->optionsKey . '[notification_subscribe]" data-group="notify_button" style="width: 430px;" value="%s" />'.
            '<p class="description">%s</p>',
            isset( $this->options['notification_subscribe'] ) ? esc_attr( $this->options['notification_subscribe']) : '',
            __('Notification message when subscribe proccess success', 'hpro-webpush')
        );
    }
    
    public function notification_unsubscribe_callback(){
        printf(
            '<input type="text" id="notification_unsubscribe" name="' . $this->optionsKey . '[notification_unsubscribe]" data-group="notify_button" style="width: 430px;" value="%s" />'.
            '<p class="description">%s</p>',
            isset( $this->options['notification_unsubscribe'] ) ? esc_attr( $this->options['notification_unsubscribe']) : '',
            __('Notification message when unsubscribe proccess success', 'hpro-webpush')
        );
    }
    
    public function notification_error_callback(){
        printf(
            '<input type="text" id="notification_error" name="' . $this->optionsKey . '[notification_error]" data-group="notify_button" style="width: 430px;" value="%s" />'.
            '<p class="description">%s</p>',
            isset( $this->options['notification_error'] ) ? esc_attr( $this->options['notification_error']) : '',
            __('Notification message when subscribtion faild', 'hpro-webpush')
        );
    }
    
    public function dialog_subscribe_callback(){
        printf(
            '<input type="text" id="dialog_subscribe" name="' . $this->optionsKey . '[dialog_subscribe]" data-group="notify_button" style="width: 430px;" value="%s" />'.
            '<p class="description">%s</p>',
            isset( $this->options['dialog_subscribe'] ) ? esc_attr( $this->options['dialog_subscribe']) : '',
            __('Confirmation dialog when user want to subscribe', 'hpro-webpush')
        );
    }
    
    public function dialog_unsubscribe_callback(){
        printf(
            '<input type="text" id="dialog_unsubscribe" name="' . $this->optionsKey . '[dialog_unsubscribe]" data-group="notify_button" style="width: 430px;" value="%s" />'.
            '<p class="description">%s</p>',
            isset( $this->options['dialog_unsubscribe'] ) ? esc_attr( $this->options['dialog_unsubscribe']) : '',
            __('Confirmation dialog when user want to unsubscribe', 'hpro-webpush')
        );
    }
}
