<?php
namespace HPROWP\Webpush;

class GeneralSettings extends BaseSettings {
    
    protected $settings = 'general';
    
    public static function getOptions() {
        return get_option('horisen_webpush_general_settings', array() );
    }
    
    public function __construct() {
        parent::__construct();
       
        register_setting(
            $this->optionsGroup, // Option group
            $this->optionsKey, // Option name
            array( $this, 'sanitize' ) // Sanitize
        );
        
        add_settings_section(
            $this->optionsSection, // ID
            __('General Settings', 'hpro-webpush'), // Title
            array( $this, 'print_section_info' ), // Callback
            $this->optionsPage // Page
        ); 
            
        add_settings_field(
            'form_uuid',
            __('Form UUID', 'hpro-webpush'), // Title
            array( $this, 'form_uuid_callback' ), 
            $this->optionsPage,
            $this->optionsSection
        );    
        
        add_settings_field(
            'application_server_key', // ID
            __('Webpush Public Key', 'hpro-webpush'), // Title
            array( $this, 'application_server_key_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section           
        );
        
        add_settings_field(
            'sdk_version', // ID
            __('Version', 'hpro-webpush'), // Title 
            array( $this, 'sdk_version_callback' ), // Callback
            $this->optionsPage, // Page
            $this->optionsSection // Section     
        );
        
    }

    protected function renderSettings() {
        parent::renderSettings();        
    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize( $input )
    {   
        $validator = new Validators\Validators();
        $new_input = array();
        
        
        $new_input['form_uuid'] = $validator->chain($input['form_uuid'], 'form_uuid' , __('Form UUID', 'hpro-webpush'),  [
                $validator->required($input['form_uuid']),
                $validator->characterLimitIs($input['form_uuid'], 36)
            ]
        );
        $new_input['application_server_key'] = $validator->chain($input['application_server_key'], 'application_server_key' , __('Webpush Public Key', 'hpro-webpush'),  [
                $validator->required($input['application_server_key'])
            ]
        );
        $new_input['sdk_version'] = $validator->chain($input['sdk_version'], 'sdk_version' , __('Version', 'hpro-webpush'), []);

        return $new_input;
    }

    public function print_section_info(){
        print __('Enter Form UUID and Webpush Public Key in your settings below', 'hpro-webpush');
    }
    
    public function form_uuid_callback(){
        printf(
            '<input type="text" id="form_uuid" style="width: 280px;" name="' . $this->optionsKey . '[form_uuid]" value="%s" />',
            isset( $this->options['form_uuid'] ) ? esc_attr( $this->options['form_uuid']) : ''
        );
    }
    
    public function sdk_version_callback(){
        echo '<select id="sdk_version" name="' . $this->optionsKey . '[sdk_version]" data-group="sdk_version">'
            . '<option value="latest" ' . (isset($this->options['sdk_version']) && $this->options['sdk_version']=='latest' ? ' selected="selected" ' : '') . '>' . __('Latest', 'hpro-webpush'). '</option>'
            . '<option value="1.1.0" ' . (isset($this->options['sdk_version']) && $this->options['sdk_version']=='1.1.0' ? ' selected="selected" ' : '') . '>1.1.0</option>'
        ;
    }
    
    public function application_server_key_callback(){
        printf(
            '<input type="text" id="application_server_key" style="width: 720px;" name="' . $this->optionsKey . '[application_server_key]" value="%s" />',
            isset( $this->options['application_server_key'] ) ? esc_attr( $this->options['application_server_key']) : ''
        );
    }
}